==> react-build-cli-0.1.4.tgz: package/src/common/webpackBar.ts <==
/*
 * @file: 
 * @author: wence
 */
import utils from '../utils';

interface WebpackBarOptions {
    width?: number;
}

export class WebpackBar {
    progress: number;
    private width: number;
    private start: number | null;
    private end: number | null;
    private stream: any;

    constructor(options?: WebpackBarOptions) {
        this.progress = 0;
        this.width = options?.width || 25;
        this.start = null;
        this.end = null;

        this.stream = process.stderr;
    }

    update(progress: number) {
        this.progress = this.getCurProgress(progress);

        if (this.start === null) {
            this.start = Date.now();
        }

        this.end = Date.now();
        this.renderBar();
    }

    getCurProgress(progress: number) {
        if (progress < 0) {
            return 0;
        }

        if (progress > 1) {
            return 100;
        }

        return Math.round(progress * 10000) / 100;
    }

    getTimeConsumed() {
        if (typeof this.end !== 'number' || typeof this.start !== 'number') {
            return 0;
        }
        return ((this.end - this.start) / 1000).toFixed(2);
    }

    renderBar() {
        const w = (this.progress / 100) * this.width;
        const bar = Array.from({length: this.width})
            .map((_: any, index: number) => {
                return index < w ? utils.chalk.blue('█') : utils.chalk.gray('█');
            }).join('');
            
        this.stream.cursorTo(0);
            
        let str: any = 'building ['
            + bar
            + `] ${this.progress}% ${this.getTimeConsumed()}s`;
        // 当到100时要换行 \n 无法使用clearLine清除
        if (this.progress === 100) {
            str += '\n';
            this.start = null;
            this.end = null;
        }
        this.stream.write(str);
        this.stream.clearLine(1);
    }
}

export default new WebpackBar();

==> react-build-cli-0.2.1.tgz: package/src/common/webpackBar.ts <==
import utils from '../utils';

interface WebpackBarOptions {
    width?: number;
}
const loadingFrames = [
    "⠋",
    "⠙",
    "⠹",
    "⠸",
    "⠼",
    "⠴",
    "⠦",
    "⠧",
    "⠇",
    "⠏"
];
export class WebpackBar {
    progress: number;
    private width: number;
    private start: number | null;
    private end: number | null;
    private stream: any;
    private frame: any;

    constructor(options?: WebpackBarOptions) {
        this.progress = 0;
        this.width = options?.width || 25;
        this.start = null;
        this.end = null;

        this.stream = process.stderr;
        this.frame = 0;
    }

    update(progress: number) {
        this.progress = this.getCurProgress(progress);

        if (this.start === null) {
            this.start = Date.now();
        }

        this.end = Date.now();
        this.renderBar();
    }

    getCurProgress(progress: number) {
        if (progress < 0) {
            return 0;
        }

        if (progress > 1) {
            return 100;
        }

        return Math.round(progress * 10000) / 100;
    }

    getTimeConsumed() {
        if (typeof this.end !== 'number' || typeof this.start !== 'number') {
            return 0;
        }
        return ((this.end - this.start) / 1000).toFixed(2);
    }

    renderBar() {
        const w = (this.progress / 100) * this.width;
        const bar = Array.from({length: this.width})
            .map((_: any, index: number) => {
                return index < w ? utils.chalk.blue('█') : utils.chalk.gray('█');
            }).join('');
            
        this.stream.cursorTo(0);

        let str: any = loadingFrames[this.frame]
            + ' building ['
            + bar
            + `] ${this.progress}% ${this.getTimeConsumed()}s`;
        // 当到100时要换行 \n 无法使用clearLine清除
        if (this.progress === 100) {
            str += '\n';
            this.start = null;
            this.end = null;
        }
        this.stream.write(str);
        this.stream.clearLine(1);

        if (this.frame > loadingFrames.length - 2) {
            this.frame = 0;
        }
        else {
            this.frame += 1;
        }
    }
}

export default new WebpackBar();
